==> rlibkriging_0.8-0.1.tar.gz: rlibkriging/tools/setup.sh <==
#!/usr/bin/env bash
set -eo pipefail

if [[ "$DEBUG_CI" == "true" ]]; then
  set -x
fi

: ${R_HOME=$(R RHOME)}
if test -z "${R_HOME}"; then
   as_fn_error $? "Could not determine R_HOME." "$LINENO" 5
fi

LIBKRIGING_SRC_PATH=src/libK

# Cleanup unused (for R) libKriging deps
rm -rf $LIBKRIGING_SRC_PATH/dependencies/Catch2
rm -rf $LIBKRIGING_SRC_PATH/dependencies/carma
rm -rf $LIBKRIGING_SRC_PATH/dependencies/pybind11
rm -rf $LIBKRIGING_SRC_PATH/dependencies/optim
rm -rf $LIBKRIGING_SRC_PATH/docs
 # then remove LinearRegressionOptim example
sed -i.bak "s/LinearRegression/##LinearRegression/g" $LIBKRIGING_SRC_PATH/src/lib/CMakeLists.txt
rm -f $LIBKRIGING_SRC_PATH/src/lib/CMakeLists.txt.bak

rm -f $LIBKRIGING_SRC_PATH/bindings/R/rlibkriging/src/linear_regression*
 # & unsuitable tests
rm -f $LIBKRIGING_SRC_PATH/bindings/R/rlibkriging/tests/testthat/test-binding-consistency.R

# Move required on upper path to avoid path length issues
if [ -d $LIBKRIGING_SRC_PATH/dependencies/lbfgsb_cpp ]; then
  rm -fr $LIBKRIGING_SRC_PATH/lbfgsb_cpp
  mv $LIBKRIGING_SRC_PATH/dependencies/lbfgsb_cpp $LIBKRIGING_SRC_PATH/.
  rm -rf $LIBKRIGING_SRC_PATH/dependencies/lbfgsb_cpp
elif [ ! -d $LIBKRIGING_SRC_PATH/lbfgsb_cpp ]; then
  echo "Cannot migrate lbfgsb_cpp dependency"
  exit 1
fi

if [ -d $LIBKRIGING_SRC_PATH/dependencies/armadillo-code ]; then
  rm -fr $LIBKRIGING_SRC_PATH/armadillo
  mkdir -p $LIBKRIGING_SRC_PATH/armadillo
  mv $LIBKRIGING_SRC_PATH/dependencies/armadillo-code/include $LIBKRIGING_SRC_PATH/armadillo/.
  mv $LIBKRIGING_SRC_PATH/dependencies/armadillo-code/src $LIBKRIGING_SRC_PATH/armadillo/.
  mv $LIBKRIGING_SRC_PATH/dependencies/armadillo-code/misc $LIBKRIGING_SRC_PATH/armadillo/.
  mv $LIBKRIGING_SRC_PATH/dependencies/armadillo-code/cmake_aux $LIBKRIGING_SRC_PATH/armadillo/.
  mv $LIBKRIGING_SRC_PATH/dependencies/armadillo-code/CMakeLists.txt $LIBKRIGING_SRC_PATH/armadillo/.
  rm -rf $LIBKRIGING_SRC_PATH/dependencies/armadillo-code
elif [ ! -d $LIBKRIGING_SRC_PATH/armadillo ]; then
  echo "Cannot migrate armadillo dependency"
  exit 1
fi
rm -fr $LIBKRIGING_SRC_PATH/dependencies

# Use custom CMakeList to hold these changes
sed -i.bak -e "s|dependencies/armadillo-code|armadillo|g" \
  $LIBKRIGING_SRC_PATH/CMakeLists.txt
sed -i.bak -e "s|dependencies/lbfgsb_cpp|lbfgsb_cpp|g" \
  $LIBKRIGING_SRC_PATH/CMakeLists.txt
sed -i.bak -e "s|configure_file(\${DOXYGEN_IN}|##configure_file(\${DOXYGEN_IN}|g" \
  $LIBKRIGING_SRC_PATH/CMakeLists.txt  
sed -i.bak -e "s|^.*CATCH_MODULE_PATH|##&|g" \
  $LIBKRIGING_SRC_PATH/CMakeLists.txt  
sed -i.bak -e "s|include(CTest)|##&|g" \
  $LIBKRIGING_SRC_PATH/CMakeLists.txt  
sed -i.bak -e "s|add_subdirectory(tests)|##&|g" \
  $LIBKRIGING_SRC_PATH/CMakeLists.txt    
sed -i.bak -e '/^add_custom_target(run_unit_tests$/,/^        )$/d;//d' \
  $LIBKRIGING_SRC_PATH/CMakeLists.txt  
rm -rf $LIBKRIGING_SRC_PATH/CMakeLists.txt.bak

# Switch slapack dependency as a local submodule (not a git clone)
sed -i.bak -e "s|https://github.com/libKriging/slapack.git|\${CMAKE_CURRENT_SOURCE_DIR}/../../slapack|g" \
  $LIBKRIGING_SRC_PATH/armadillo/cmake_aux/Modules/ARMA_FindLAPACK.cmake
sed -i.bak -e "s|GIT_REPOSITORY|SOURCE_DIR|g" \
  $LIBKRIGING_SRC_PATH/armadillo/cmake_aux/Tools/build_external_project.cmake

# .travis-ci -> travis-ci (hidden files not allowed in CRAN)
if [ -d $LIBKRIGING_SRC_PATH/.travis-ci ]; then
  mv $LIBKRIGING_SRC_PATH/.travis-ci $LIBKRIGING_SRC_PATH/travis-ci
fi
# rename .travis-ci in travis-ci everywhere. Use temp .bak for sed OSX compliance
find $LIBKRIGING_SRC_PATH -type f -exec sed -i.bak "s/\.travis-ci/travis-ci/g" {} +
find $LIBKRIGING_SRC_PATH -type f -name *.bak -exec rm -f {} +;


RLIBKRIGING_PATH=$LIBKRIGING_SRC_PATH"/bindings/R/rlibkriging/"

# overwrite libK/src/Makevars* with ./src/Makevars*
cp src/Makevars* $RLIBKRIGING_PATH/src/.

# copy resources from libK/binding/R
rm -rf R
cp -r $RLIBKRIGING_PATH/R .
rm -rf src/*.cpp
cp -r $RLIBKRIGING_PATH/src .
cp -r $RLIBKRIGING_PATH/NAMESPACE .
rm -rf tests
cp -r $RLIBKRIGING_PATH/tests .
# detailed tests
#  remove previous loading of previous custom testthat & rlibkriging (that should not be there, anyway)
find tests/testthat -type f -name test-*.R -exec sed -i.bak -e 's|library(testthat)|#library(testthat)|g' {} +
find tests/testthat -type f -name test-*.R -exec sed -i.bak -e 's|library(rlibkriging|#library(rlibkriging|g' {} +
#  prepend loading of testthat
mv tests/testthat/test-*.R tests/.
for f in `ls -d tests/*.R`; do
  echo -e "library(testthat)\n Sys.setenv('OMP_THREAD_LIMIT'=2)\n library(rlibkriging)\n" > $f.new
  echo "$(cat $f)" >> $f.new
  mv $f.new $f
done
rm -rf tests/testthat/
rm -rf tests/testthat.R
# disable cholesky tests for fedora timeout (still to investigate deeper...)
rm -rf tests/test-KrigingCholCrash.R

# sync man content
rm -rf man
"${R_HOME}"/bin/R -e "roxygen2::roxygenise(package.dir = '.')"
rm -rf $LIBKRIGING_SRC_PATH/build

==> rlibkriging_0.9-0.tar.gz: rlibkriging/tools/setup.sh <==
#!/usr/bin/env bash
set -eo pipefail

if [[ "$DEBUG_CI" == "true" ]]; then
  set -x
fi

: ${R_HOME=$(R RHOME)}
if test -z "${R_HOME}"; then
   as_fn_error $? "Could not determine R_HOME." "$LINENO" 5
fi

LIBKRIGING_SRC_PATH=src/libK

# Cleanup unused (for R) libKriging deps
rm -rf $LIBKRIGING_SRC_PATH/dependencies/Catch2
rm -rf $LIBKRIGING_SRC_PATH/dependencies/carma
rm -rf $LIBKRIGING_SRC_PATH/dependencies/pybind11
rm -rf $LIBKRIGING_SRC_PATH/dependencies/optim
rm -rf $LIBKRIGING_SRC_PATH/docs
 # then remove LinearRegressionOptim example
sed -i.bak "s/LinearRegression/##LinearRegression/g" $LIBKRIGING_SRC_PATH/src/lib/CMakeLists.txt
rm -f $LIBKRIGING_SRC_PATH/src/lib/CMakeLists.txt.bak

rm -f $LIBKRIGING_SRC_PATH/bindings/R/rlibkriging/src/linear_regression*
 # & unsuitable tests
rm -f $LIBKRIGING_SRC_PATH/bindings/R/rlibkriging/tests/testthat/test-binding-consistency.R

# Move required on upper path to avoid path length issues
if [ -d $LIBKRIGING_SRC_PATH/dependencies/lbfgsb_cpp ]; then
  rm -fr $LIBKRIGING_SRC_PATH/lbfgsb_cpp
  mv $LIBKRIGING_SRC_PATH/dependencies/lbfgsb_cpp $LIBKRIGING_SRC_PATH/.
  rm -rf $LIBKRIGING_SRC_PATH/dependencies/lbfgsb_cpp
elif [ ! -d $LIBKRIGING_SRC_PATH/lbfgsb_cpp ]; then
  echo "Cannot migrate lbfgsb_cpp dependency"
  exit 1
fi

if [ -d $LIBKRIGING_SRC_PATH/dependencies/armadillo-code ]; then
  rm -fr $LIBKRIGING_SRC_PATH/armadillo
  mkdir -p $LIBKRIGING_SRC_PATH/armadillo
  mv $LIBKRIGING_SRC_PATH/dependencies/armadillo-code/include $LIBKRIGING_SRC_PATH/armadillo/.
  mv $LIBKRIGING_SRC_PATH/dependencies/armadillo-code/src $LIBKRIGING_SRC_PATH/armadillo/.
  mv $LIBKRIGING_SRC_PATH/dependencies/armadillo-code/misc $LIBKRIGING_SRC_PATH/armadillo/.
  mv $LIBKRIGING_SRC_PATH/dependencies/armadillo-code/cmake_aux $LIBKRIGING_SRC_PATH/armadillo/.
  mv $LIBKRIGING_SRC_PATH/dependencies/armadillo-code/CMakeLists.txt $LIBKRIGING_SRC_PATH/armadillo/.
  rm -rf $LIBKRIGING_SRC_PATH/dependencies/armadillo-code
elif [ ! -d $LIBKRIGING_SRC_PATH/armadillo ]; then
  echo "Cannot migrate armadillo dependency"
  exit 1
fi
rm -fr $LIBKRIGING_SRC_PATH/dependencies

# Use custom CMakeList to hold these changes
sed -i.bak -e "s|dependencies/armadillo-code|armadillo|g" \
  $LIBKRIGING_SRC_PATH/CMakeLists.txt
sed -i.bak -e "s|dependencies/lbfgsb_cpp|lbfgsb_cpp|g" \
  $LIBKRIGING_SRC_PATH/CMakeLists.txt
sed -i.bak -e "s|configure_file(\${DOXYGEN_IN}|##configure_file(\${DOXYGEN_IN}|g" \
  $LIBKRIGING_SRC_PATH/CMakeLists.txt
sed -i.bak -e "s|^.*CATCH_MODULE_PATH|##&|g" \
  $LIBKRIGING_SRC_PATH/CMakeLists.txt
sed -i.bak -e "s|include(CTest)|##&|g" \
  $LIBKRIGING_SRC_PATH/CMakeLists.txt
sed -i.bak -e "s|add_subdirectory(tests)|##&|g" \
  $LIBKRIGING_SRC_PATH/CMakeLists.txt
sed -i.bak -e '/^add_custom_target(run_unit_tests$/,/^        )$/d;//d' \
  $LIBKRIGING_SRC_PATH/CMakeLists.txt
rm -rf $LIBKRIGING_SRC_PATH/CMakeLists.txt.bak

# Disable pragma that inhibit warnings
sed -i.bak -e "s|#pragma|//&|g" \
  $LIBKRIGING_SRC_PATH/src/lib/include/libKriging/utils/nlohmann/json.hpp
rm -rf $LIBKRIGING_SRC_PATH/src/lib/include/libKriging/utils/nlohmann/json.hpp.bak

# Switch slapack dependency as a local submodule (not a git clone)
sed -i.bak -e "s|https://github.com/libKriging/slapack.git|\${CMAKE_CURRENT_SOURCE_DIR}/../../slapack|g" \
  $LIBKRIGING_SRC_PATH/armadillo/cmake_aux/Modules/ARMA_FindLAPACK.cmake
sed -i.bak -e "s|GIT_REPOSITORY|SOURCE_DIR|g" \
  $LIBKRIGING_SRC_PATH/armadillo/cmake_aux/Tools/build_external_project.cmake

# .travis-ci -> travis-ci (hidden files not allowed in CRAN)
if [ -d $LIBKRIGING_SRC_PATH/.travis-ci ]; then
  mv $LIBKRIGING_SRC_PATH/.travis-ci $LIBKRIGING_SRC_PATH/travis-ci
fi
# rename .travis-ci in travis-ci everywhere. Use temp .bak for sed OSX compliance
find $LIBKRIGING_SRC_PATH -type f -exec sed -i.bak "s/\.travis-ci/travis-ci/g" {} +
# remove usages of 'git rev-parse', which is not a standard requirement fo R
GIT_ROOT=$(pwd);
while [ "$GIT_ROOT" != "/" ]; do
  if [ -d "$GIT_ROOT/.git" ]; then
    break;
  fi;
  GIT_ROOT=$(dirname "$GIT_ROOT");
done
export GIT_ROOT
find $LIBKRIGING_SRC_PATH -type f -exec sed -i.bak "s|\$(git rev-parse --show-toplevel)|$GIT_ROOT|g" {} +
# cleanup
find $LIBKRIGING_SRC_PATH -type f -name *.bak -exec rm -f {} +;


RLIBKRIGING_PATH=$LIBKRIGING_SRC_PATH"/bindings/R/rlibkriging/"

# overwrite libK/src/Makevars* with ./src/Makevars*
cp src/Makevars* $RLIBKRIGING_PATH/src/.

# copy resources from libK/binding/R
rm -rf R
cp -r $RLIBKRIGING_PATH/R .
rm -rf src/*.cpp
cp -r $RLIBKRIGING_PATH/src .
cp -r $RLIBKRIGING_PATH/NAMESPACE .
rm -rf tests
cp -r $RLIBKRIGING_PATH/tests .
# detailed tests
#  remove previous loading of previous custom testthat & rlibkriging (that should not be there, anyway)
find tests/testthat -type f -name test-*.R -exec sed -i.bak -e 's|library(testthat)|#library(testthat)|g' {} +
find tests/testthat -type f -name test-*.R -exec sed -i.bak -e 's|library(rlibkriging|#library(rlibkriging|g' {} +
#  prepend loading of testthat
mv tests/testthat/test-*.R tests/.
for f in `ls -d tests/test-*.R`; do
  echo -e "library(testthat)\n Sys.setenv('OMP_THREAD_LIMIT'=2)\n library(rlibkriging)\n" > $f.new
  echo "$(cat $f)" >> $f.new
  mv $f.new $f
  # reduce tests time by shrinking number of simulations, iterations, and points of testing
  sed -i.bak -e "s|,101)|,5)|g" $f # less sample in seq(...,101)
  rm -f $f.bak
  sed -i.bak -e "s|,51)|,5)|g" $f # less sample in seq(...,51)
  rm -f $f.bak
  sed -i.bak -e "s|,21)|,5)|g" $f # less sample in seq(...,21)
  rm -f $f.bak
  sed -i.bak -e "s|n <- 10|n <- 1|g" $f # less sample: /10
  rm -f $f.bak
  sed -i.bak -e "s|simulate(1000,|simulate(100,|g" $f # less sample in simulate
  rm -f $f.bak
  sed -i.bak -e "s|p.value > 0.0|p.value > 0.00|g" $f # also reduce p-value threshold, because of simulate sample size reduction
  rm -f $f.bak
  sed -i.bak -e "s|for (i in 1:length(.x)) { for (j in 1:length(.x)) {|for (i in 1:length(.x)) { j=i; {|g" $f # avoid full factorial sampling in 2d
  rm -f $f.bak
  sed -i.bak -e "s|ntest <- 100|ntest <- 10|g" $f
  rm -f $f.bak
  sed -i.bak -e "s|\(.\+\)mean_deriv\[i\]|#&|g" $f # rm some canary test
  rm -f $f.bak
  sed -i.bak -e "s|\(.\+\)stdev_deriv\[i\]|#&|g" $f # rm some canary test
  rm -f $f.bak
done
rm -rf tests/testthat/
rm -rf tests/testthat.R
# disable cholesky tests for fedora timeout (still to investigate deeper...)
rm -rf tests/test-KrigingCholCrash.R
rm -rf tests/demo*
rm -rf tests/bench*
rm -rf tests/bug*

# sync man content
rm -rf man
"${R_HOME}"/bin/R -e "roxygen2::roxygenise(package.dir = '.')"
rm -rf $LIBKRIGING_SRC_PATH/build
